@@ -2,6 +2,9 @@ mod error;
 mod interface;
 mod target;
 
+#[cfg(any(target_os = "linux", target_os = "macos"))]
+mod utils;
+
 pub use error::*;
 
 use self::interface::NetworkInterface;
